==> kubernetes-model-4.5.0-sources.jar: io/fabric8/kubernetes/api/model/SecretFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SecretFluent<A extends SecretFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToData(String key,String value);
    public A addToData(Map<String,String> map);
    public A removeFromData(String key);
    public A removeFromData(Map<String,String> map);
    public Map<String,String> getData();
    public A withData(Map<String,String> data);
    public Boolean hasData();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public SecretFluent.MetadataNested<A> withNewMetadata();
    public SecretFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public SecretFluent.MetadataNested<A> editMetadata();
    public SecretFluent.MetadataNested<A> editOrNewMetadata();
    public SecretFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToStringData(String key,String value);
    public A addToStringData(Map<String,String> map);
    public A removeFromStringData(String key);
    public A removeFromStringData(Map<String,String> map);
    public Map<String,String> getStringData();
    public A withStringData(Map<String,String> stringData);
    public Boolean hasStringData();
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<SecretFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> kubernetes-model-4.9.1-sources.jar: io/fabric8/kubernetes/api/model/SecretFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SecretFluent<A extends SecretFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToData(String key,String value);
    public A addToData(Map<String,String> map);
    public A removeFromData(String key);
    public A removeFromData(Map<String,String> map);
    public Map<String,String> getData();
    public A withData(Map<String,String> data);
    public Boolean hasData();
    public Boolean isImmutable();
    public A withImmutable(Boolean immutable);
    public Boolean hasImmutable();
    public A withNewImmutable(String arg1);
    public A withNewImmutable(boolean arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public SecretFluent.MetadataNested<A> withNewMetadata();
    public SecretFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public SecretFluent.MetadataNested<A> editMetadata();
    public SecretFluent.MetadataNested<A> editOrNewMetadata();
    public SecretFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToStringData(String key,String value);
    public A addToStringData(Map<String,String> map);
    public A removeFromStringData(String key);
    public A removeFromStringData(Map<String,String> map);
    public Map<String,String> getStringData();
    public A withStringData(Map<String,String> stringData);
    public Boolean hasStringData();
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<SecretFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
